package
Version:
v0.0.0-...-dab46ad
Opens a new window with list of versions in this module.
Published: Mar 24, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CloserAdd(level int, event func() (errs []error))
CloserAdd 添加关闭事件 level 等级越低越先关闭
func Inject(handler func(err error))
Inject 关闭时发生错误处理方法
func JSON(data interface{}) []byte
JSON 屏蔽错误返回json字节
func JSONWithColor(data interface{}) []byte
JSONWithColor 屏蔽错误返回json格式化带颜色字节
func PrintJSONWithColor(data interface{})
PrintJSONWithColor .
Source Files
¶
Click to show internal directories.
Click to hide internal directories.